import json

from openai import OpenAI

client = (
    OpenAI()
)  # default to OPENAI_API_URL and OPENAI_API_KEY system environment variables

completion = client.chat.completions.create(
    model="gpt-3.5-turbo",
    messages=[
        {"role": "system", "content": "You are a helpful assistant."},
        {"role": "user", "content": "What is FastAPI?"},
    ],
)

print(json.dumps(completion.model_dump(), indent=2))

# print(completion.choices[0].message.content)



import json
import os

import openai

client = openai.OpenAI( # AnyScale API is OpenAI client-compatible
    base_url=os.environ["ANYSCALE_BASE_URL"],
    api_key=os.environ["ANYSCALE_API_KEY"],
)

chat_completion = client.chat.completions.create(
    model="meta-llama/Llama-2-7b-chat-hf",
    messages=[{"role": "user", "content": "Who is Einstein?"}],
)

print(json.dumps(chat_completion.model_dump(), indent=2))

# print(chat_completion.model_dump())



import huggingface_hub

client = huggingface_hub.InferenceClient() # default to HF_TOKEN environment variable

# print(client.fill_mask("Hello I'm a <mask> model."))
print(
    client.translation(
        "Llamakey: one master key for many cloud AI APIs.", model="t5-small"
    )
)



import json, os

from openai import OpenAI # Perplexity API is OpenAI client-compatible

client = OpenAI(
    api_key=os.environ["PERPLEXITY_API_KEY"], 
    base_url=os.environ["PERPLEXITY_BASE_URL"]
)

messages = [{"role": "user", "content": ("How many stars are in the universe?")}]

response = client.chat.completions.create(model="pplx-7b-chat", messages=messages)

print(json.dumps(response.model_dump(), indent=2))

# print(response.choices[0].message.content)


import vectara

client = vectara.vectara()

corpus_id = client.create_corpus("lmk test corpus")

client.upload(corpus_id, "../../README.md", description="LlaMasterKey README.md")

result = client.query(corpus_id, "What is LlaMasterKey?", top_k=5)
print(result)

client.reset_corpus(corpus_id)



import json

import cohere

co = cohere.Client()  # API key default to CO_API_KEY

# generate a prediction for a prompt
prediction = co.chat(message="How many days in a year?")

# print the predicted text
print(f"The response from Cohere Chat API is \n ===========\n  {prediction.text}")
